@@ -8,6 +8,7 @@ import (
 	"gitlab.com/gitlab-org/gitlab-shell/internal/command/readwriter"
 	"gitlab.com/gitlab-org/gitlab-shell/internal/config"
 	"gitlab.com/gitlab-org/gitlab-shell/internal/executable"
+	"gitlab.com/gitlab-org/gitlab-shell/internal/logger"
 )
 
 func main() {
@@ -29,6 +30,8 @@ func main() {
 		os.Exit(1)
 	}
 
+	logger.Configure(config)
+
 	cmd, err := command.New(executable, os.Args[1:], config, readWriter)
 	if err != nil {
 		fmt.Fprintf(readWriter.ErrOut, "%v\n", err)
