@@ -2,14 +2,18 @@ package uploadarchive
 
 import (
 	"bytes"
+	"strings"
 	"testing"
 
+	"github.com/sirupsen/logrus"
+
 	"github.com/stretchr/testify/require"
 
 	"gitlab.com/gitlab-org/gitlab-shell/internal/command/commandargs"
 	"gitlab.com/gitlab-org/gitlab-shell/internal/command/readwriter"
 	"gitlab.com/gitlab-org/gitlab-shell/internal/config"
 	"gitlab.com/gitlab-org/gitlab-shell/internal/gitlabnet/testserver"
+	"gitlab.com/gitlab-org/gitlab-shell/internal/testhelper"
 	"gitlab.com/gitlab-org/gitlab-shell/internal/testhelper/requesthandlers"
 )
 
@@ -33,8 +37,13 @@ func TestUploadPack(t *testing.T) {
 		ReadWriter: &readwriter.ReadWriter{ErrOut: output, Out: output, In: input},
 	}
 
+	hook := testhelper.SetupLogger()
+
 	err := cmd.Execute()
 	require.NoError(t, err)
 
 	require.Equal(t, "UploadArchive: "+repo, output.String())
+	require.Equal(t, logrus.InfoLevel, hook.LastEntry().Level)
+	require.True(t, strings.Contains(hook.LastEntry().Message, "executing git command"))
+	require.True(t, strings.Contains(hook.LastEntry().Message, "command=git-upload-archive"))
 }
